@@ -1258,7 +1258,7 @@ class ListAuthorizedApplicationsToUserRequest(AbstractModel):
         """
         :param UserId: 用户 ID。
         :type UserId: str
-        :param IncludeInheritedAuthorizations: 查询范围是否包括用户关联的用户组、组织机构的应用访问权限。默认为不查询 。传0表示不查询该范围，传1表示应用查询该范围。
+        :param IncludeInheritedAuthorizations: 查询范围是否包括用户关联的用户组、组织机构的应用访问权限。默认为不查询 。传false表示不查询该范围，传true表示应用查询该范围。
         :type IncludeInheritedAuthorizations: bool
         """
         self.UserId = None
